#include "map_win.h"
#include <set>

bool MapWin::closeIfEscapeIsPressed(GdkEventKey* e)
{
  if(e->keyval==GDK_Escape)
  {
    mytab.closeMapWin();
    //    hide();
  }
  return true;
}

MapWin::MapWin(const std::string& title, std::vector<std::string> eml, std::vector<std::string> nml, NoteBookTab & mw):mytab(mw)
{
  set_title(title);
  set_default_size(200, 50);

  set_resizable(false);

  signal_key_press_event().connect(sigc::mem_fun(*this, &MapWin::closeIfEscapeIsPressed));

  mytab.signal_title_ch().connect(sigc::mem_fun(*this, &MapWin::set_title));

  e_combo_array=new MapSelector * [EDGE_PROPERTY_NUM];

  table=new Gtk::Table(EDGE_PROPERTY_NUM, 1, false);

  for(int i=0;i<EDGE_PROPERTY_NUM;i++)
  {
    e_combo_array[i]=new MapSelector(eml, mytab.getActiveEdgeMap(i), edge_property_strings[i], true);

    (*table).attach((*(e_combo_array[i])),0,1,i,i+1,Gtk::SHRINK,Gtk::SHRINK,10,3);

    e_combo_array[i]->signal_cbt_ch().connect(sigc::bind(sigc::mem_fun(*this, &MapWin::edgeMapChanged), i));
    e_combo_array[i]->signal_newmapwin_needed().connect(sigc::mem_fun(*this, &MapWin::newMapWinNeeded));
  }

  vbox.pack_start(*(new Gtk::Label("Edge properties")));

  vbox.pack_start(*table);

  vbox.pack_start(*(new Gtk::HSeparator));

  n_combo_array=new MapSelector * [NODE_PROPERTY_NUM];

  table=new Gtk::Table(NODE_PROPERTY_NUM, 1, false);

  for(int i=0;i<NODE_PROPERTY_NUM;i++)
  {
    n_combo_array[i]=new MapSelector(nml, mytab.getActiveNodeMap(i), node_property_strings[i], false);

    (*table).attach((*(n_combo_array[i])),0,1,i,i+1,Gtk::SHRINK,Gtk::SHRINK,10,3);

    n_combo_array[i]->signal_cbt_ch().connect(sigc::bind(sigc::mem_fun(*this, &MapWin::nodeMapChanged), i));
    n_combo_array[i]->signal_newmapwin_needed().connect(sigc::mem_fun(*this, &MapWin::newMapWinNeeded));
  }

  add(vbox);

  vbox.pack_start(*(new Gtk::Label("Node properties")));

  vbox.pack_start(*table);

  show_all_children();

}

void MapWin::nodeMapChanged(std::string mapname, int prop)
{
  mytab.propertyChange(false, prop, mapname);
}

void MapWin::edgeMapChanged(std::string mapname, int prop)
{
  mytab.propertyChange(true, prop, mapname);
}

void MapWin::newMapWinNeeded(bool itisedge)
{
  mytab.popupNewMapWin(itisedge);
}

void MapWin::update(std::vector<std::string> eml, std::vector<std::string> nml)
{
  for(int i=0;i<EDGE_PROPERTY_NUM;i++)
  {
    e_combo_array[i]->update_list(eml);
  }

  for(int i=0;i<NODE_PROPERTY_NUM;i++)
  {
    n_combo_array[i]->update_list(nml);
  }

  mytab.active_maps_needed();
}

void MapWin::registerNewEdgeMap(std::string newmapname)
{
  for(int i=0;i<EDGE_PROPERTY_NUM;i++)
  {
    //filling in combo box with choices
    e_combo_array[i]->append_text((Glib::ustring)newmapname);
  }
}

void MapWin::registerNewNodeMap(std::string newmapname)
{
  for(int i=0;i<NODE_PROPERTY_NUM;i++)
  {
    //filling in combo box with choices
    n_combo_array[i]->append_text((Glib::ustring)newmapname);
  }
}

bool MapWin::on_delete_event(GdkEventAny * event)
{
  event=event;
  mytab.closeMapWin();
  return true;
}

void MapWin::changeEntry(bool isitedge, int prop, std::string mapname)
{
  if(isitedge)
    {
      e_combo_array[prop]->set_active_text(mapname);
    }
  else
    {
      n_combo_array[prop]->set_active_text(mapname);
    }
}

void MapWin::set_title(std::string tabname)
{
  Gtk::Window::set_title("Map Setup - "+tabname);
}
